</p>
<p align="left">
<a href="https://github.com/DhruvBisla/PlusPortalsAPI/actions">
    <img src="https://github.com/DhruvBisla/PlusportalsAPI/workflows/Tests/badge.svg" alt="Test Status">
</a>
<a href="https://pypi.org/project/plusportals/">
    <img src="https://badge.fury.io/py/plusportals.svg" alt="Package Version">
</a>
</p>

# PlusPortalsAPI
A reverse-engineered PlusPortals API
